@@ -36,7 +36,7 @@ class App(object):
         self.app = FastAPI(title='AppZoo')
         # self.app = app_
 
-        self.verbose = verbose  # 是否返回请求体
+        self.verbose = verbose  # 是否返回请求体 # todo删除
 
         # 原生接口
         self.get = self.app.get
@@ -78,12 +78,12 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def add_apps(self, app_dir='apps', **kwargs):
+    def add_apps(self, app_dir='apps', main_func='main', **kwargs):
         """加载当前app_dir文件夹下的所有app（递归）, 入口函数都是main
         1. 过滤掉 _ 开头的py文件
         2. 支持单文件
 
-        appcli easy-run app_dir
+        appcli easy-run <app_dir>
         """
 
         app_home = Path(sys_path_append(app_dir))
@@ -93,15 +93,16 @@ class App(object):
 
         routes = []
         for p in app_home.rglob(pattern):
-            if not p.stem.startswith('_'):  # 过滤_开头的py
-                home_parts = p.parts[n:]
-                route = f'/{app_home.stem}/' + "/".join(home_parts)[:-3]
-                routes.append(route)
+            home_parts = p.parts[n:]
+            route = f'/{app_home.stem}/' + "/".join(home_parts)[:-3]
+            module = importlib.import_module('.'.join(home_parts)[:-3])
 
-                func = importlib.import_module('.'.join(home_parts)[:-3]).main
+            if hasattr(module, main_func):
+                func = getattr(module, main_func)
                 self.add_route(route, func, method='POST', **kwargs)
+                routes.append(route)
             else:
-                logger.warning(f"Filter: {p.stem}")
+                logger.warning(f"Filter: {p}")
 
         logger.info(f"Add Routes: {routes}")
 
@@ -158,7 +159,7 @@ class App(object):
 
         # todo: def get_and_post(request: Request):
         # query_input = request.query_params._dict
-        # body_input = await request.request.json()
+        # body_input = await request.json()
 
         else:
             async def handler():
@@ -167,20 +168,23 @@ class App(object):
         return handler
 
     def _try_func(self, kwargs, func, result_key='data', **kwargs_):
+        __debug = 1 if kwargs.pop('__debug', 0) else 0
+
         input = kwargs
         output = OrderedDict()
+        output['error_code'] = 0
+        output['error_msg'] = "SUCCESS"
 
-        if self.verbose:
+        if __debug:
             output['requestParams'] = input
+            output['timestamp'] = time.ctime()
 
         try:
-            output['success'] = 1
             output[result_key] = func(**input)
 
         except Exception as error:
-            output['success'] = 0
-            output['error'] = error
-            output['errorPlus'] = traceback.format_exc().strip()
+            output['error_code'] = 1  # 通用错误
+            output['error_msg'] = traceback.format_exc().strip() if __debug else error  # debug状态获取详细信息
 
         finally:
             output.update(kwargs_)
@@ -201,5 +205,5 @@ if __name__ == '__main__':
     app.add_route('/get', lambda **kwargs: kwargs, method="GET", result_key="GetResult")
     app.add_route('/post', lambda **kwargs: kwargs, method="POST", result_key="PostResult")
 
-    # app.run(port=9000, debug=False, reload=False, access_log=True)
-    # app.run(f"{app.app_file_name(__file__)}", port=9000, debug=False, reload=False)
+    app.run(port=9000, debug=False, reload=False, access_log=True)
+    # app.run(f"{app.app_from(__file__)}", port=9000, debug=False, reload=False) # app_的在 __main__ 之上
